import requests

from .helpers import (
    CPI_ROOT_URL,
    APITestCase,
)


def get_channels():
    url = '{}/api/v1/channels'.format(CPI_ROOT_URL)
    response = requests.get(url)
    return response


def get_channel(name):
    url = '{}/api/v1/channels/{}'.format(CPI_ROOT_URL, name)
    response = requests.get(url)
    return response


class ChannelsTestCase(APITestCase):

    def assert_channels(self, response):
        body = response.json()
        # assert generic embedded data structure
        self.assertIn('_embedded', body)
        self.assertIn('clickindex:channel', body['_embedded'])
        # assert there is at least one result
        self.assertGreater(len(body['_embedded']['clickindex:channel']), 0)
        # assert result data structure
        channel_data = body['_embedded']['clickindex:channel']
        channel_names = ('stable', 'candidate', 'beta', 'edge')
        for item, name in zip(channel_data, channel_names):
            self._assert_channel_data(item, name=name)

    def assert_channel(self, response, name):
        body = response.json()
        # assert result data structure
        self._assert_channel_data(body, name=name)

    def _assert_channel_data(self, data, name=None):
        self.assertIn('promotion_order', data)
        self.assertIn('display_name', data)
        self.assertIn('name', data)
        if name is not None:
            self.assertEqual(data['name'], name)

    def test_get_channels(self):
        response = get_channels()
        self.assert_success(response)
        self.assert_channels(response)

    def test_get_channel(self):
        response = get_channel('edge')
        self.assert_success(response)
        self.assert_channel(response, 'edge')
