import requests

from .helpers import (
    CPI_ROOT_URL,
    APITestCase,
)


def get_frameworks():
    url = '{}/api/v1/frameworks'.format(CPI_ROOT_URL)
    response = requests.get(url)
    return response


def get_framework(name):
    url = '{}/api/v1/frameworks/{}'.format(CPI_ROOT_URL, name)
    response = requests.get(url)
    return response


class FrameworksTestCase(APITestCase):

    def assert_frameworks(self, response):
        body = response.json()
        # assert generic embedded data structure
        self.assertIn('_embedded', body)
        self.assertIn('clickindex:framework', body['_embedded'])
        # assert there is at least one result
        self.assertGreater(len(body['_embedded']['clickindex:framework']), 0)
        # assert result data structure
        item = body['_embedded']['clickindex:framework'][0]
        self._assert_framework_data(item)

    def assert_framework(self, response, name):
        body = response.json()
        # assert result data structure
        self._assert_framework_data(body, name=name)

    def _assert_framework_data(self, data, name=None):
        self.assertIn('enable_unauthenticated_downloads', data)
        self.assertIn('policy_vendor', data)
        self.assertIn('policy_version', data)
        self.assertIn('state', data)
        self.assertIn('name', data)
        if name is not None:
            self.assertEqual(data['name'], name)

    def test_get_frameworks(self):
        response = get_frameworks()
        self.assert_success(response)
        self.assert_frameworks(response)

    def test_get_framework(self):
        response = get_framework(name='ubuntu-sdk-15.04')
        self.assert_success(response)
        self.assert_framework(response, name='ubuntu-sdk-15.04')

    def test_get_framework_not_found(self):
        response = get_framework(name='invalid')
        self.assert_not_found(response, message='No such framework')
