import requests

from .helpers import (
    CPI_ROOT_URL,
    APITestCase,
)


def get_highlights():
    url = '{}/api/v1/highlights'.format(CPI_ROOT_URL)
    response = requests.get(url)
    return response


def get_highlight(slug):
    url = '{}/api/v1/highlights/{}'.format(CPI_ROOT_URL, slug)
    response = requests.get(url)
    return response


class HighlightsTestCase(APITestCase):

    def assert_highlights(self, response):
        body = response.json()
        # assert generic embedded data structure
        self.assertIn('_embedded', body)
        self.assertIn('clickindex:highlight', body['_embedded'])
        # assert there is at least one result
        self.assertGreater(len(body['_embedded']['clickindex:highlight']), 0)
        # assert result data structure
        item = body['_embedded']['clickindex:highlight'][0]
        self._assert_highlight_data(item)

    def assert_highlight(self, response, slug):
        body = response.json()
        # assert result data structure
        self._assert_highlight_data(body, slug=slug)

    def _assert_highlight_data(self, data, slug=None):
        self.assertIn('name', data)
        self.assertIn('description', data)
        self.assertIn('country_code', data)
        self.assertIn('slug', data)
        if slug is not None:
            self.assertEqual(data['slug'], slug)

    def test_get_highlights(self):
        response = get_highlights()
        self.assert_success(response)
        self.assert_highlights(response)

    def test_get_highlight(self):
        response = get_highlight(slug='top-apps')
        self.assert_success(response)
        self.assert_highlight(response, slug='top-apps')

    def test_get_highlight_not_found(self):
        response = get_highlight(slug='missing')
        self.assert_not_found(
            response, message="No such highlight u'missing'")

    def test_get_highlight_invalid_slug(self):
        response = get_highlight(slug='top-apps:en')
        self.assert_not_found(
            response, message="No such highlight u'top-apps:en'")
