import requests

from .helpers import (
    CPI_ROOT_URL,
    APITestCase,
)


def get_recommendation(slug):
    url = '{}/api/v1/recommendations/{}'.format(CPI_ROOT_URL, slug)
    response = requests.get(url)
    return response


class RecommendationsTestCase(APITestCase):

    def assert_recommendation(self, response, slug=None):
        body = response.json()
        # assert result data structure
        self.assertIn('applications', body)
        self.assertGreater(len(body['applications']), 0)
        self.assertIn('hotwords', body)
        self.assertIn('slug', body)
        if slug is not None:
            self.assertEqual(body['slug'], slug)

    def test_get_recommendation(self):
        response = get_recommendation('hello')
        self.assert_success(response)
        self.assert_recommendation(response, 'hello')

    def test_get_recommendation_not_found(self):
        response = get_recommendation('missing')
        self.assert_not_found(
            response, message="No such recommendation u'missing'")
